# encoding: utf-8
import requests
from bs4 import BeautifulSoup


PARSE_TAGS = ["url", "title", "type", "image", "description"]


class NoHtmlProvided(Exception):
    def __init__(self, message="No HTML was provided for parsed url"):
        self.message = message


class BadResponse(Exception):
    def __init__(self, code):
        self.message = "Server responded with: {}".format(code)


def _parse_tag(soup, tag):
    elem = soup.find("meta", {"property": "og:{}".format(tag)})
    if not elem or not elem.get("content"):
        return None
    return elem["content"]


def parse(url, parse_tags=PARSE_TAGS):
    r = requests.get(url)
    if not r.ok:
        raise BadResponse(r.status_code)
    if not r.content:
        raise NoHtmlProvided

    soup = BeautifulSoup(r.content, features="html.parser")
    parsed_data = {}
    for tag in parse_tags:
        tag_data = _parse_tag(soup, tag)
        if tag_data:
            parsed_data[tag] = _parse_tag(soup, tag)

    return parsed_data



from setuptools import setup


with open("README.md") as f:
    long_description = f.read()


setup(
    name="opengrapher",
    packages=["opengrapher"],
    version="0.2.2",
    description="Utility for parsing the OpenGraph tags",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Topic :: Text Processing :: Markup :: HTML",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords="opengraph",
    author="Maxim Semenov",
    author_email="0rang3max@gmail.com",
    url="https://github.com/0rang3max/opengrapher",
    download_url="https://github.com/0rang3max/opengrapher/archive/v0.2.tar.gz",
    license="MIT",
    include_package_data=True,
    python_requires=">=3.4",
    install_requires=["beautifulsoup4", "requests"],
    entry_points="""
      # -*- Entry points: -*-
    """,
)
